#
# spec file for package python-happybase
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-happybase
Version:        1.2.0
Release:        4.2
Summary:        A Python library to interact with Apache HBase
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/wbolster/happybase
Source:         https://github.com/wbolster/happybase/archive/%{version}.tar.gz
# https://github.com/python-happybase/happybase/pull/238
Patch0:         use_pytest.patch
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module thriftpy2}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
Requires:       python-six
Requires:       python-thriftpy2 >= 0.4
BuildArch:      noarch
%python_subpackages

%description
HappyBase is a Python library to interact with Apache HBase.

%package -n python-happybase-doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
Provides:       %{python_module happybase-doc = %{version}}

%description -n python-happybase-doc
HappyBase is a Python library to interact with Apache HBase.

This package contains the documentation.

%prep
%autosetup -p1 -n happybase-%{version}

%build
%python_build
sphinx-build -b html doc docs/build/html

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
rm -r docs/build/html/.[a-z]*

%check
# the api tests need running thrift server
%pytest tests/test_util.py

%files %{python_files}
%license LICENSE.rst
%doc NEWS.rst README.rst TODO.rst
%{python_sitelib}/*

%files -n python-happybase-doc
%license LICENSE.rst
%doc docs/build/html

%changelog
* Thu Mar 14 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro: allows us to eliminate usage of deprecated
  %%patchN.
* Mon Nov  8 2021 Dirk Müller <dmueller@suse.com>
- add missing six buildrequires
* Tue Mar 31 2020 Paolo Stivanin <info@paolostivanin.com>
- Switch from nose to pytest
- Add use_pytest.patch
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.0:
  * Switch from thriftpy to its successor thriftpy2, which supports Python 3.7.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Sep 17 2017 bwiedemann@suse.com
- Drop environment.pickle from doc to make build reproducible
* Sun Aug 27 2017 jengelh@inai.de
- Ensure neutrality of descriptions.
* Fri Aug 25 2017 tbechtold@suse.com
- update to 1.1.0:
  * Set socket timeout unconditionally on ``TSocket``
  * Add new ‘0.98’ compatibility mode
  * Add support for reversed scanners
  * From now on this library uses a semantic versioning scheme.
    HappyBase is a mature library, but always used 0.x version numbers
    for no good reason. This has now changed.
  * Finally, Python 3 support. Thanks to all the people who contributed!
  * Switch to thriftpy as the underlying Thrift library, which is a much
    nicer and better maintained library.
  * Enable building universal wheels
- convert to singlespec
- split -doc package
* Wed May  6 2015 benoit.monin@gmx.fr
- update to version 0.9:
  * Fix an issue where scanners would return fewer results than
    expected due to HBase not always behaving as its documentation
    suggests (issue #72).
  * Add support for the Thrift compact protocol (TCompactProtocol)
    in :py:class:`Connection` (issue #70).
* Tue Apr 15 2014 dmueller@suse.com
- update to 0.8:
  * Add (and default to) '0.96' compatibility mode in :py:class:`Connection`.
  * Add support for retrieving sorted columns, which is possible with the HBase
  0.96 Thrift API
  * The `batch_size` argument to :py:meth:`Table.scan` is no longer propagated to
  `Scan.setBatching()` at the Java side (inside the Thrift server).
* Mon Dec  9 2013 p.drouand@gmail.com
- Update to version 0.7
  * Added a `wal` argument to various data manipulation methods on the
    :py:class:`Table` and :py:class:`Batch` classes to determine whether
    to write the mutation to the Write-Ahead Log (WAL). (`issue #36
    <https://github.com/wbolster/happybase/issues/36>`_).
  * Pass batch_size to underlying Thrift Scan instance (`issue #38
    <https://github.com/wbolster/happybase/issues/38>`_).
  * Expose server name and port in :py:meth:`Table.regions` (recent HBase
    versions only) (`issue #37
    <https://github.com/wbolster/happybase/issues/37>`_).
  * Regenerated bundled Thrift API modules using a recent upstream
    Thrift APIdefinition. This is required to expose newly added API.
- Package NEWS.rst, TODO.rst and html pages in documentation directory
- Add python-Sphinx requirement to build html documentation
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Thu Jul 11 2013 dmueller@suse.com
- update to 0.6:
  * Rewrote exception handling in connection pool. Exception handling is now a lot
  cleaner and does not introduce cyclic references anymore. (`issue #25
  <https://github.com/wbolster/happybase/issues/25>`_).
  * Regenerated bundled Thrift code using Thrift 0.9.0 with the new-style classes
  flag (`issue #27 <https://github.com/wbolster/happybase/issues/27>`_).
* Mon Jun 10 2013 dmueller@suse.com
- update to 0.5:
  * Added a thread-safe connection pool (:py:class:`ConnectionPool`)
  * The :py:meth:`Connection.delete_table` method now features an optional
  `disable` parameter to make deleting enabled tables easier.
  * The debug log message emitted by :py:meth:`Table.scan` when closing a scanner
  * Increased Thrift dependency to at least 0.8.
  * The :py:class:`Connection` constructor now features an optional `timeout`
  parameter
  * The `timestamp` argument to various methods now also accepts `long` values
  * In some corner cases exceptions were raised during interpreter shutdown
* Fri Apr  5 2013 speilicke@suse.com
- Define python_sitelib to fix SLE_11_SP1 build
* Wed Mar 13 2013 speilicke@suse.com
- Install documetation
- Run testsuite
- Fix runtime dependencies, needs python-thrift
* Wed Mar 13 2013 dmueller@suse.com
- Initial packaging (0.4)
